@@ -19,14 +19,14 @@
 #ifndef INFOCOMBOBOX_H
 #define INFOCOMBOBOX_H
 
-#include <QtGui/QComboBox>
+#include <QComboBox>
 
 class InfoComboBox : public QComboBox
 {
 	Q_OBJECT
 
 public:
-	InfoComboBox( QWidget *parent = 0 );
+	InfoComboBox( QWidget *parent = nullptr );
 
 	/**
 	 * Set read only mode for the combo box
@@ -37,7 +37,7 @@ public:
 	void setReadOnly( bool readOnly );
 	bool isReadOnly() const;
 
-	virtual void showPopup();
+	void showPopup() Q_DECL_OVERRIDE;
 
 private:
 	bool mReadOnly;
